@@ -8,16 +8,18 @@ from pathlib import Path
 
 import vdf
 
-from .util import lower_dict, is_flatpak_sandbox
+from .flatpak import is_flatpak_sandbox
+from .util import lower_dict
 
 __all__ = (
     "COMMON_STEAM_DIRS", "SteamApp", "find_steam_path",
-    "find_legacy_steam_runtime_path", "get_appinfo_sections",
-    "get_tool_appid", "find_steam_compat_tool_app", "find_appid_proton_prefix",
-    "find_proton_app", "get_steam_lib_paths", "get_compat_tool_dirs",
-    "get_custom_compat_tool_installations_in_dir", "get_custom_compat_tool_installations",
-    "find_current_steamid3", "get_appid_from_shortcut",
-    "get_custom_windows_shortcuts", "get_steam_apps"
+    "find_legacy_steam_runtime_path", "iter_appinfo_sections",
+    "get_appinfo_sections", "get_tool_appid", "find_steam_compat_tool_app",
+    "find_appid_proton_prefix", "find_proton_app", "get_steam_lib_paths",
+    "get_compat_tool_dirs", "get_custom_compat_tool_installations_in_dir",
+    "get_custom_compat_tool_installations", "find_current_steamid3",
+    "get_appid_from_shortcut", "get_custom_windows_shortcuts",
+    "get_steam_apps", "is_steam_deck"
 )
 
 COMMON_STEAM_DIRS = [
@@ -25,6 +27,15 @@ COMMON_STEAM_DIRS = [
     ".local/share/Steam"
 ]
 
+OS_RELEASE_PATHS = [
+    "/run/host/os-release",  # The host file if we're inside a Flatpak sandbox
+    "/etc/os-release"
+]
+
+# 'cache/appinfo.vdf' contains a VDF section with metadata about
+# "Proton name -> app ID" mappings with this app ID
+STEAM_PLAY_MANIFESTS_APPID = 891390
+
 logger = logging.getLogger("protontricks")
 
 
@@ -378,10 +389,10 @@ APPINFO_STRUCT_HEADER = "<4sL"
 APPINFO_STRUCT_SECTION = "<LLLLQ20sL"
 
 
-def get_appinfo_sections(path):
+def iter_appinfo_sections(path):
     """
-    Parse an appinfo.vdf file and return all the deserialized binary VDF
-    objects inside it
+    Parse an appinfo.vdf file and iterate through all the binary VDF objects
+    inside it
     """
     # appinfo.vdf is not actually a (binary) VDF file, but a binary file
     # containing multiple binary VDF sections.
@@ -401,8 +412,6 @@ def get_appinfo_sections(path):
     if magic != b"'DV\x07":
         raise SyntaxError("Invalid file magic number")
 
-    sections = []
-
     section_size = struct.calcsize(APPINFO_STRUCT_SECTION)
     while True:
         # We don't need any of the fields besides 'entry_size',
@@ -418,55 +427,41 @@ def get_appinfo_sections(path):
 
         vdf_d = vdf.binary_loads(data[i:i+vdf_section_size])
         vdf_d = lower_dict(vdf_d)
-        sections.append(vdf_d)
+        yield vdf_d
 
         i += vdf_section_size
 
         if i == len(data) - 4:
-            return sections
+            return
 
 
-def get_tool_appid(compat_tool_name, appinfo_path):
+def get_appinfo_sections(path):
+    """
+    Parse an appinfo.vdf file and return all the deserialized binary VDF
+    objects inside it
+    """
+    return list(iter_appinfo_sections(path))
+
+
+def get_tool_appid(compat_tool_name, steam_play_manifest):
     """
     Get the App ID for compatibility tool by the compat tool name
     used in STEAM_DIR/config/config.vdf
     """
-    # Parse all the individual VDF sections in appinfo.vdf to a list
-    vdf_sections = get_appinfo_sections(appinfo_path)
+    compat_tools = steam_play_manifest["appinfo"]["extended"]["compat_tools"]
 
-    for section in vdf_sections:
-        if not section.get("appinfo", {}).get("extended", {}).get(
-                "compat_tools", None):
-            continue
+    for default_name, entry in compat_tools.items():
+        # A single compatibility tool may have multiple valid names
+        # eg. "proton_316" and "proton_316_beta"
+        aliases = [default_name]
 
-        compat_tools = section["appinfo"]["extended"]["compat_tools"]
+        # Each compat tool entry can also contain an 'aliases' field
+        # with a different compat tool name
+        if "aliases" in entry:
+            aliases += entry["aliases"].split(",")
 
-        for default_name, entry in compat_tools.items():
-            # A single compatibility tool may have multiple valid names
-            # eg. "proton_316" and "proton_316_beta"
-            aliases = [default_name]
-
-            # Each compat tool entry can also contain an 'aliases' field
-            # with a different compat tool name
-            if "aliases" in entry:
-                # All of the appinfo.vdf files encountered so far
-                # only have a single string inside the "aliases" field,
-                # but let's assume the field could be a list of strings
-                # as well
-                if isinstance(entry["aliases"], str):
-                    aliases.append(entry["aliases"])
-                elif isinstance(entry["aliases"], list):
-                    aliases += entry["aliases"]
-                else:
-                    raise TypeError(
-                        "Unexpected type {} for 'fields' in "
-                        "appinfo.vdf".format(type(aliases))
-                    )
-
-            if compat_tool_name in aliases:
-                return entry["appid"]
-
-    logger.error("Could not find the Steam Play manifest in appinfo.vdf")
+        if compat_tool_name in aliases:
+            return entry["appid"]
 
     return None
 
@@ -482,17 +477,49 @@ def find_steam_compat_tool_app(steam_path, steam_apps, appid=None):
     The compatibility tool *may* not be a Proton installation. This can be
     checked using `SteamApp.is_proton`.
     """
-    # 1. Find the name of compatibility tool in use
-    #    from STEAM_DIR/config/config.vdf
-    # 2. If the compatibility tool's name can be found directly
-    #    in the list of apps we discovered earlier, return that
-    # 3. ...or if the name can't be found that way, parse
-    #    the file in STEAM_DIR/appcache/appinfo.vdf to find the compatibility
-    #    tool's App ID
+    def _get_tool_app(compat_tool_name, steam_apps, steam_play_manifest):
+        tool_appid = get_tool_appid(compat_tool_name, steam_play_manifest)
+
+        if not tool_appid:
+            return None
+
+        try:
+            app = next(
+                app for app in steam_apps if app.appid == tool_appid
+            )
+            return app
+        except StopIteration:
+            return None
+
+    # Determine which Proton version to use (either globally or for
+    # a specific app if `appid` was provided) by checking
+    # `<steam_dir>/config/config.vdf` and `<steam_dir>/appcache/appinfo.vdf`.
+    # Multiple configuration values might be found. In such case, select the
+    # one with the highest priority.
     config_vdf_path = steam_path / "config" / "config.vdf"
     content = config_vdf_path.read_text()
 
     vdf_data = lower_dict(vdf.loads(content))
+
+    appinfo_path = steam_path / "appcache" / "appinfo.vdf"
+    appinfo_sections = [
+        section for section in iter_appinfo_sections(appinfo_path)
+        if section["appinfo"]["appid"] in (STEAM_PLAY_MANIFESTS_APPID, appid)
+    ]
+    steam_play_manifest = next(
+        section for section in appinfo_sections
+        if section["appinfo"]["appid"] == STEAM_PLAY_MANIFESTS_APPID
+    )
+
+    try:
+        app_section = next(
+            section for section in appinfo_sections
+            if section["appinfo"]["appid"] == appid
+        )
+    except StopIteration:
+        # App ID was most likely not provided
+        app_section = None
+
     # ToolMapping seems to be used in older Steam beta releases
     try:
         tool_mapping = (
@@ -512,26 +539,78 @@ def find_steam_compat_tool_app(steam_path, steam_apps, appid=None):
     except KeyError:
         compat_tool_mapping = {}
 
-    compat_tool_name = None
-
     # The name of potential names in order of priority
-    potential_names = [
-        compat_tool_mapping.get(str(appid), {}).get("name", None),
-        compat_tool_mapping.get("0", {}).get("name", None),
-        tool_mapping.get(str(appid), {}).get("name", None),
-        tool_mapping.get("0", {}).get("name", None)
-    ]
-    # Get the first name that was valid
+    potential_names = []
+
+    # Game specific user settings have the 1st priority, if they exist
+    if compat_tool_mapping.get(str(appid), {}).get("name"):
+        tool_name = compat_tool_mapping[str(appid)]["name"]
+        logger.info(
+            "User has configured app Proton version (CompatToolMapping): %s",
+            tool_name
+        )
+        potential_names.append(tool_name)
+
+    # Steam Deck compatibility profile has the 2nd highest priority
+    if app_section and is_steam_deck():
+        logger.info(
+            "We're on a Steam Deck, checking if compatibility profile is "
+            "available for the app"
+        )
+        recommended_runtime = (
+            app_section["appinfo"]
+            .get("common", {})
+            .get("steam_deck_compatibility", {})
+            .get("configuration", {})
+            .get("recommended_runtime", None)
+        )
+
+        if recommended_runtime not in (None, "native"):
+            logger.info(
+                "App has Steam Deck compatibility profile with Proton "
+                "version: %s",
+                recommended_runtime
+            )
+            potential_names.append(recommended_runtime)
+
+    # Global user settings have the 3rd highest priority
+    if compat_tool_mapping.get("0", {}).get("name"):
+        tool_name = compat_tool_mapping["0"]["name"]
+        logger.info(
+            "User has configured default Proton version (CompatToolMapping): "
+            "%s",
+            tool_name
+        )
+        potential_names.append(tool_name)
+
+    # Legacy user settings (ToolMapping) have the 4th highest priority
+    if tool_mapping.get(str(appid), {}).get("name", {}):
+        tool_name = tool_mapping[str(appid)]["name"]
+        logger.info(
+            "User has configured app Proton version (ToolMapping): %s",
+            tool_name
+        )
+        potential_names.append(tool_name)
+
+    if tool_mapping.get("0", {}).get("name", {}):
+        tool_name = tool_mapping["0"]["name"]
+        logger.info(
+            "User has configured default Proton version (ToolMapping): %s",
+            tool_name
+        )
+        potential_names.append(tool_name)
+
+    # Get the first name that was valid, or use stable Proton as fallback
     try:
         compat_tool_name = next(name for name in potential_names if name)
     except StopIteration:
-        logger.error(
-            "No compatibility tool found in config.vdf. "
-            "Have you enabled Steam Play for all titles under Steam settings?"
+        logger.info(
+            "No compatibility tool found by reading Steam configuration. "
+            "Using stable version of Proton as fallback."
         )
-        return None
+        compat_tool_name = "proton-stable"
 
-    # We've got the name from config.vdf,
+    # We've got a compatibility tool name,
     # now there are two possible ways to find the installation
     # 1. It's a custom compatibility tool, and we simply need to find
     #    a SteamApp by its internal name
@@ -540,7 +619,9 @@ def find_steam_compat_tool_app(steam_path, steam_apps, appid=None):
 
     # Let's try option 1 first
     try:
-        app = next(app for app in steam_apps if app.name == compat_tool_name)
+        app = next(
+            app for app in steam_apps if app.name == compat_tool_name
+        )
         logger.info(
             "Found active custom compatibility tool: %s", app.name
         )
@@ -550,24 +631,19 @@ def find_steam_compat_tool_app(steam_path, steam_apps, appid=None):
 
     # Try option 2:
     # Find the corresponding App ID from <steam_path>/appcache/appinfo.vdf
-    appinfo_path = steam_path / "appcache" / "appinfo.vdf"
-    tool_appid = get_tool_appid(compat_tool_name, appinfo_path)
+    tool_app = _get_tool_app(
+        compat_tool_name=compat_tool_name,
+        steam_apps=steam_apps,
+        steam_play_manifest=steam_play_manifest
+    )
 
-    if not tool_appid:
-        logger.error(
-            "Could not find compatibility tool's App ID from appinfo.vdf"
-        )
-        return None
-
-    # We've now got the appid. Return the corresponding SteamApp
-    try:
-        app = next(app for app in steam_apps if app.appid == tool_appid)
+    if tool_app:
         logger.info(
-            "Found active compatibility tool: %s", app.name
+            "Found active compatibility tool: %s", tool_app.name
         )
-        return app
-    except StopIteration:
-        return None
+        return tool_app
+
+    logger.error("Could not find configured Proton installation!")
 
 
 def find_appid_proton_prefix(appid, steam_lib_paths):
@@ -1059,3 +1135,20 @@ def get_steam_apps(steam_root, steam_path, steam_lib_paths):
     steam_apps.sort(key=lambda app: app.name)
 
     return steam_apps
+
+
+def is_steam_deck():
+    """
+    Check if we're running on a Steam Deck
+    """
+    for path in OS_RELEASE_PATHS:
+        try:
+            lines = Path(path).read_text("utf-8").split("\n")
+        except FileNotFoundError:
+            continue
+
+        if "ID=steamos" in lines and "VARIANT_ID=steamdeck" in lines:
+            logger.info("The current device is a Steam Deck")
+            return True
+
+    return False
